==========
Change log
==========

0.1.0 (2018-05-10)
------------------

* Initial release.


0.1.1 (2018-06-11)
------------------

* ModuleNotFoundError is a new exception in Python 3.6, whereas earlier versions use ImportError.


0.1.2 (2018-07-27)
------------------

* Add progress bar that indicates the progress of the anonymization operation.


0.2.0 (2018-10-28)
------------------

* Added tests
* Small code refactors
